# 20221027_v0.9.9_base_prod


New full base prod with lstchain v0.9.9 and all declinations and nodes currently available.
Commented stages > merge, so only the DL1 will be produced.
Training will be done dec wise depending on required tunings / lstchain configs.

```
lstmcpipe_generate_config PathConfigAllSkyFull --prod_id 20221027_v0.9.9_base_prod --dec_list dec_2276  dec_3476  dec_4822  dec_6166  dec_6676  dec_931  dec_min_2924  dec_min_413
```


